# Generated by roxygen2: do not edit by hand

export(Get_AdmUnNames)
export(Get_BroadBand)
export(Get_DB_MIUR)
export(Get_InnerAreas)
export(Get_Invalsi_IS)
export(Get_Registry)
export(Get_School2mun)
export(Get_Shapefile)
export(Get_nstud)
export(Get_nteachers_prov)
export(Group_DB_MIUR)
export(Group_nstud)
export(Group_teachers4stud)
export(Map_DB)
export(Map_Invalsi)
export(Map_School_Buildings)
export(Set_DB)
export(Util_Check_nstud_availability)
export(Util_DB_MIUR_num)
export(Util_Invalsi_filter)
export(Util_nstud_wide)
import(sf)
importFrom(magrittr,"%<>%")
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
