#' @keywords internal
#'
tabrename.manual <- function(){
  manualdf <- data.frame(
    Input = c("ANNOSCOLASTICO", "ACCESSODAESTERNOCONRAMPE","ACCESSOPIAZZOLA","ACCESSORAMPE","ACCORGIMENTIRIDUZIONECONSUMIENERGETICI",
              "ACCORGIMENTISUPERAMENTOBARRIEREARCHITETTONICHE", "ADEGUAMENTOSISMICO",
              "ALTRECRITICITASPECIFICHE","ALTRIACCORGIMENTI","ALTRIACCORGIMENTIDISABILI",
              "ALTRIACCORGIMENTIRIDUZIONECONSUMI","ALTRIUSI","ALTRO","ALTROIMPIANTORISCALDAMENTO","ALTROSPECIFICARE","ALTROTIPOISOLAMENTO",
              "ANNOADATTAMENTO","ANNOCOSTRUZIONE","AREAALTREMOTIVAZIONI","AREAGRANDETRAFFICO","AREAINDUSTRIEABBANDONATE",
              "AREAINDUSTRIERISCHIO","AREANONRECINTATA","AREASICURA","AREATRANSITIFERROVIARI","AREAURBANADEGRADATA","ASCENSOREDISABILI",
              "ASCENSORETRASPORTODISABILI","ASSENZAPIAZZOLAADEGUATA","ATTESTAZIONERINNOVOPERIODICOCONFORMITAANTINCENDIO","AUDITORIUM",
              "AULAMAGNA","AULE","AULEINFORMATICHE","AULETECNICHE","CAP","CENTRALIZZATOARIA","CENTRALIZZATOGASOLIO","CENTRALIZZATOGPL",
              "CENTRALIZZATOMETANO","CENTRALIZZATOOLIOCOMBUSTIBILE","CENTRALIZZATOOLIOCOMBUSTIBILI","CERTIFICATOAGIBILITAABITABILITA",
              "CERTIFICATOCOLLAUDOIMPIANTOSPEGNIMENTO","CERTIFICATOCOLLAUDOSTATICO","CERTIFICATOOMOLOGAZIONECENTRALETERMICA",
              "CERTIFICATOPREVENZIONEINCENDI","CERTIFICATOPREVENZIONEINCENDICPI","CERTIFICATOSEGNALAZIONEAGIBILITA",
              "CLASSIFICAZIONESISMICANAZIONALE","CODICECOMUNE","CODICEEDIFICIO","CODICESCUOLA","CONDIZIONAMENTOVENTILAZIONE",
              "CONTESTOSENZADISTURBI","CORPISCALDANTIELETTRICIAUTONOMI","CRITICITASPECIFICHEAREASCOLASTICA","DENOMINAZIONEINDIRIZZO",
              "DESCRIZIONECOMUNE","DOCUMENTOVALUTAZIONERISCHI","DOCUMENTOVALUTAZIONERISCHIO","DOPPIVETRISERRAMENTI","EDIFICIOTUTELATO",
              "EDIFICIOVETUSTO","FASCIAETAADATTAMENTO","FASCIAETACOSTRUZIONE","IMPIANTOFOTOVOLTAICO","IMPIANTORISCALDAMENTO",
              "IMPIANTOSOLARETERMICO","ISOLAMENTOACUSTICO","ISOLAMENTOACUSTICORUMOROSITAESTERNA","ISOLAMENTOCOPERTURA",
              "ISOLAMENTOCOPERTURE","ISOLAMENTOINTERNO","ISOLAMENTOINTERNOAULE","ISOLAMENTOINTERNOPIANI","ISOLAMENTOINTERNOPIANIDIVERSI",
              "ISOLAMENTOPARETIESTERNE","ISOLAMENTORUMORIESTERNI","LIBRETTOOMOLOGAZIONEINAILCENTRALETERMICA","MENSA",
              "MEZZIPRIVATI", "MIGLIORAMENTOSISMICO", "NULLAOSTAPROVVISORIOPREVENZIONEINCENDINOP","NUMEROCIVICO","NUMEROCOMPLESSIVOPIANI","NUMEROPIANI",
              "PALESTRA","PALESTRAPISCINA","PANNELLISOLARI","PERCORSIESTERNI","PERCORSIESTERNIDISABILI","PERCORSIINTERNI",
              "PERCORSIINTERNIDISABILI","PERIODOADATTAMENTO","PERIODOCOSTRUZIONE","PIANOEMERGENZA","PIANOEVACUAZIONE",
              "PIATTAFORMAELEVATRICE","PISCINA","PISTACICLABILE","PORTELARGHEZZADISABILI","PORTELARGHEZZAMINIMA",
              "PREESISTENZEINDUSTRIALIABBANDONATE","PRESENZAGRANDETRAFFICO","PRESENZATRANSITOFERROVIARIO",
              "PROGETTAZIONEANTISISMICA","PROGETTATONORMATIVATECNICAANTISISMICA",
              "RISCALDAMENTOALTRANATURA","SCALEANORMA","SCALENORMA","SCIAANTINCENDIO",
              "SCUOLABUS","SERVIZIIGIENICIDISABILI","SERVIZIIGIENICISPECIFICINORMADISABILI","SERVOSCALAPIATTAFORMAELEVATRICE",
              "SIGLAPROVINCIA","SPAZIAMMINISTRATIVI","SPAZIAMMINISTRAZIONE","SPAZICOLLETTIVI","SPAZIDIDATTICA",
              "SPAZIDIDATTICI","SPERFICIEAREALIBERA","SPERFICIEAREATOTALE","STATOEDIFICIO","SUPERAMENTOBARRIEREARCH",
              "SUPERFICIETOTALEAREALIBERA","SUPERFICIETOTALEAREASCOLASTICA","TELERISCALDAMENTO","TIPOLOGIAINDIRIZZO",
              "TRASPORTIFERROVIARI","TRASPORTIPUBBLICIINTERURBANI","TRASPORTIPUBBLICIURBANI","TRASPORTODISABILI",
              "USOSCOLASTICO","VETRIDOPPISERRAMENTIDOPPI","VICINANZAACQUEINQUINANTI","VICINANZAALTRIDISTURBI",
              "VICINANZACIMITERI","VICINANZADISCARICA","VICINANZAFONTIINQUINAMENTOACUSTICO","VICINANZAFONTIINQUINAMENTOATMOSFERICO",
              "VICINANZAINDUSTRIEARISCHIO","VICINANZAINDUSTRIEINQUINANTI","VICINANZAINQUINAMENTOACUSTICO",
              "VICINANZAINQUINAMENTOATMOSFERICO","VICINANZARADIAZIONIELETTROMAGNETICHE","VICINANZASORGENTIRADIAZIONIELETTROMAGNETICHE",
              "VINCOLIIDROGEOLOGICI","VINCOLIPAESAGGIO","VINCOLOIDROGEOLOGICO","VINCOLOINTERESSECULTURALE",
              "VINCOLOPAESAGGISTICO","VOLUME","VOLUMELORDOEDIFICIO","ZONASISMICA","ZONAURBANADEGRADATA","ZONIZZAZIONEIMPIANTOTERMICO"),
    file1 =c("ANNO_SCOLASTICO","ACCESSO_DA_ESTERNO_CON_RAMPE","","ACCESSO_DA_ESTERNO_CON_RAMPE","ACCORGIMENTI_RIDUZIONE_CONSUMI_ENERGETICI",
             "ACCORGIMENTI_SUPERAMENTO_BARRIERE_ARCHITETTONICHE","ADEGUAMENTO_SISMICO", "ALTRE_CRITICITA_SPECIFICHE","ALTRI_ACCORGIMENTI",
             "ALTRI_ACCORGIMENTI","","ALTRI_USI","ALTRO","ALTRO_IMPIANTO_RISCALDAMENTO","ALTRO_SPECIFICARE","",
             "ANNO_ADATTAMENTO","ANNO_COSTRUZIONE","","PRESENZA_GRANDE_TRAFFICO","PREESISTENZE_INDUSTRIALI_ABBANDONATE",
             "VICINANZA_INDUSTRIE_A_RISCHIO","AREA_NON_RECINTATA","","PRESENZA_TRANSITO_FERROVIARIO","ZONA_URBANA_DEGRADATA",
             "ASCENSORE_TRASPORTO_DISABILI","ASCENSORE_TRASPORTO_DISABILI","ASSENZA_PIAZZOLA_ADEGUATA",
             "ATTESTAZIONE_RINNOVO_PERIODICO_CONFORMITA_ANTINCENDIO","AUDITORIUM","","AULE","AULE_INFORMATICHE",
             "AULE_TECNICHE","CAP","","CENTRALIZZATO_GASOLIO","CENTRALIZZATO_GPL","CENTRALIZZATO_METANO",
             "CENTRALIZZATO_OLIO_COMBUSTIBILE","CENTRALIZZATO_OLIO_COMBUSTIBILE","","","","","CERTIFICATO_PREVENZIONE_INCENDI",
             "CERTIFICATO_PREVENZIONE_INCENDI","CERTIFICATO_SEGNALAZIONE_AGIBILITA","CLASSIFICAZIONE_SISMICA_NAZIONALE",
             "Municipality_code","CODICE_EDIFICIO","School_code","CONDIZIONAMENTO_VENTILAZIONE","CONTESTO_SENZA_DISTURBI",
             "CORPI_SCALDANTI_ELETTRICI_AUTONOMI","CRITICITA_SPECIFICHE_AREA_SCOLASTICA","DENOMINAZIONE_INDIRIZZO",
             "DESCRIZIONE_COMUNE","DOCUMENTO_VALUTAZIONE_RISCHI","DOCUMENTO_VALUTAZIONE_RISCHIO","VETRI_DOPPI_SERRAMENTI_DOPPI",
             "EDIFICIO_TUTELATO","","","","IMPIANTO_FOTOVOLTAICO","IMPIANTO_RISCALDAMENTO","IMPIANTO_SOLARE_TERMICO",
             "ISOLAMENTO_ACUSTICO","ISOLAMENTO_ACUSTICO_RUMOROSITA_ESTERNA","ISOLAMENTO_COPERTURE","ISOLAMENTO_COPERTURE",
             "ISOLAMENTO_INTERNO","","","ISOLAMENTO_INTERNO_PIANI_DIVERSI","ISOLAMENTO_PARETI_ESTERNE","",
             "LIBRETTO_OMOLOGAZIONE_INAIL_CENTRALE_TERMICA","MENSA","MEZZI_PRIVATI","MIGLIORAMENTO_SISMICO","","NUMERO_CIVICO","NUMERO_COMPLESSIVO_PIANI",
             "NUMERO_COMPLESSIVO_PIANI","PALESTRA","","","PERCORSI_ESTERNI","PERCORSI_ESTERNI","PERCORSI_INTERNI",
             "PERCORSI_INTERNI","PERIODO_ADATTAMENTO","PERIODO_COSTRUZIONE","","PIANO_EVACUAZIONE","",
             "PISCINA","PISTA_CICLABILE","PORTE_LARGHEZZA_MINIMA","PORTE_LARGHEZZA_MINIMA","PREESISTENZE_INDUSTRIALI_ABBANDONATE",
             "PRESENZA_GRANDE_TRAFFICO","PRESENZA_TRANSITO_FERROVIARIO","","","","SCALE_A_NORMA","SCALE_A_NORMA",
             "SCIA_ANTINCENDIO","SCUOLABUS","SERVIZI_IGIENICI_SPECIFICI_NORMA_DISABILI","SERVIZI_IGIENICI_SPECIFICI_NORMA_DISABILI",
             "SERVOSCALA_PIATTAFORMA_ELEVATRICE","SIGLA_PROVINCIA","SPAZI_AMMINISTRAZIONE","SPAZI_AMMINISTRAZIONE",
             "SPAZI_COLLETTIVI","SPAZI_DIDATTICA","SPAZI_DIDATTICA","SUPERFICIE_TOTALE_AREA_LIBERA","SUPERFICIE_TOTALE_AREA_SCOLASTICA",
             "","","SUPERFICIE_TOTALE_AREA_LIBERA","SUPERFICIE_TOTALE_AREA_SCOLASTICA","TELERISCALDAMENTO",
             "TIPOLOGIA_INDIRIZZO","TRASPORTI_FERROVIARI","TRASPORTI_PUBBLICI_INTERURBANI","TRASPORTI_PUBBLICI_URBANI",
             "TRASPORTO_DISABILI","USO_SCOLASTICO","VETRI_DOPPI_SERRAMENTI_DOPPI","VICINANZA_ACQUE_INQUINANTI",
             "VICINANZA_ALTRI_DISTURBI","VICINANZA_CIMITERI","VICINANZA_DISCARICA","VICINANZA_FONTI_INQUINAMENTO_ACUSTICO",
             "VICINANZA_FONTI_INQUINAMENTO_ATMOSFERICO","VICINANZA_INDUSTRIE_A_RISCHIO","VICINANZA_INDUSTRIE_INQUINANTI",
             "VICINANZA_FONTI_INQUINAMENTO_ACUSTICO","VICINANZA_FONTI_INQUINAMENTO_ATMOSFERICO",
             "VICINANZA_SORGENTI_RADIAZIONI_ELETTROMAGNETICHE","VICINANZA_SORGENTI_RADIAZIONI_ELETTROMAGNETICHE",
             "VINCOLO_IDROGEOLOGICO","VINCOLO_PAESAGGISTICO","VINCOLO_IDROGEOLOGICO","VINCOLO_INTERESSE_CULTURALE",
             "VINCOLO_PAESAGGISTICO","VOLUME_LORDO_EDIFICIO","VOLUME_LORDO_EDIFICIO","","ZONA_URBANA_DEGRADATA","ZONIZZAZIONE_IMPIANTO_TERMICO"),
    file2 = c("ANNO_SCOLASTICO","","ACCESSO_PIAZZOLA","ACCESSO_RAMPE","","","","","","ALTRI_ACCORGIMENTI_DISABILI",
              "ALTRI_ACCORGIMENTI_RIDUZIONE_CONSUMI","","","","","ALTRO_TIPO_ISOLAMENTO","","","AREA_ALTRE_MOTIVAZIONI",
              "AREA_GRANDE_TRAFFICO","AREA_INDUSTRIE_ABBANDONATE","AREA_INDUSTRIE_RISCHIO","","AREA_SICURA","AREA_TRANSITI_FERROVIARI",
              "AREA_URBANA_DEGRADATA","ASCENSORE_DISABILI","","","","","AULA_MAGNA","","","","","CENTRALIZZATO_ARIA","","","","",
              "CENTRALIZZATO_OLIO_COMBUSTIBILI","CERTIFICATO_AGIBILITA_ABITABILITA","CERTIFICATO_COLLAUDO_IMPIANTO_SPEGNIMENTO",
              "CERTIFICATO_COLLAUDO_STATICO","CERTIFICATO_OMOLOGAZIONE_CENTRALE_TERMICA","","CERTIFICATO_PREVENZIONE_INCENDI_CPI",
              "","","","","","","","","","","","","DOCUMENTO_VALUTAZIONE_RISCHIO","DOPPI_VETRI_SERRAMENTI","","EDIFICIO_VETUSTO",
              "FASCIA_ETA_ADATTAMENTO","FASCIA_ETA_COSTRUZIONE","","","","","","ISOLAMENTO_COPERTURA","","","ISOLAMENTO_INTERNO_AULE",
              "ISOLAMENTO_INTERNO_PIANI","","","ISOLAMENTO_RUMORI_ESTERNI","","","","","NULLA_OSTA_PROVVISORIO_PREVENZIONE_INCENDI_NOP","","",
              "NUMERO_PIANI","","PALESTRA_PISCINA","PANNELLI_SOLARI","","PERCORSI_ESTERNI_DISABILI","","PERCORSI_INTERNI_DISABILI","","",
              "PIANO_EMERGENZA","","PIATTAFORMA_ELEVATRICE","","","PORTE_LARGHEZZA_DISABILI","","","","","","PROGETTAZIONE_ANTISISMICA",
              "RISCALDAMENTO_ALTRA_NATURA","","SCALE_NORMA","","","SERVIZI_IGIENICI_DISABILI","","","","SPAZI_AMMINISTRATIVI","","","",
              "SPAZI_DIDATTICI","SPERFICIE_AREA_LIBERA","SPERFICIE_AREA_TOTALE","STATO_EDIFICIO","SUPERAMENTO_BARRIERE_ARCH","","","",
              "","","","","","","","","","","","","","","","VICINANZA_INQUINAMENTO_ACUSTICO","VICINANZA_INQUINAMENTO_ATMOSFERICO",
              "VICINANZA_RADIAZIONI_ELETTROMAGNETICHE","","VINCOLI_IDROGEOLOGICI","VINCOLI_PAESAGGIO","","","","VOLUME","","ZONA_SISMICA","",""),
    Readable = c("School_year", "External_access_ramps", "Layby_access", "Outside_access_ramps",
                 "Energy_saving_devices", "Architectural_barriers_overcoming_devices", "Seismic_adaptation",
                 "Other_specific_criticalities", "Other_devices", "Other_devices", "Other_consumption_reduction_devices",
                 "Other_uses", "Other", "Other_heating_system", "Other_specify", "Other_insulation_type",
                 "Adaptation_year", "Building_year", "Area_other_motivations", "Large_traffic",
                 "Abandoned_industries", "Risky_industries_proximity", "Unenclosed_area",
                 "Secure_area", "Railway_traffic", "Decayed_urban_area", "Disabled_people_elevator",
                 "Disabled_people_elevator", "Layby_absence", "Periodic_fire_safety_compliance_renewal",
                 "Auditorium", "Main_hall", "Classrooms", "IT_classrooms", "Technology_classrooms", "Postal_code", "Central_air_system",
                 "Centralised_diesel_oil_system", "Centralised_LPG_system", "Centralised_methane_system", "Centralised_fuel_oil_system",
                 "Centralised_fuel_oil_system", "Occupancy_certificate", "Shutdown_system_testing_certification",
                 "Static_testing_certification", "Thermal_plant_approval_certification", "Fire_prevention_certification",
                 "Fire_prevention_certification", "Occupancy_report_certification", "National_seismic_classification",
                 "Municipality_code", "Building_code", "School_code", "Ventilation_conditioning", "Undisturbed_context",
                 "Autonomous_electric_heating_elements", "School_area_specific_criticalities", "Address_name",
                 "Municipality_description", "Risk_assessment_document", "Risk_assesment_document",
                 "Double_windows_glazing", "Protected_building", "Ancient_building", "Adaptation_age_range",
                 "Building_age_range", "Photovoltaic_system", "Heating_system", "Solar_heating_system",
                 "Acoustic_insulation", "Acoustic_insulation_outside_noise", "Covers_insulation",
                 "Covers_insulation", "Internal_insulation", "Classrooms_internal_insulation", "Floors_internal_insulation",
                 "Different_floors_internal_insulation", "Outside_walls_insulation", "Outside_noise_insulation",
                 "Thermal_plant_INAIL_certification_booklet", "Canteen", "Private_transport", "Seismic_improvement", "Provisional_fire_prevention_clearance",
                 "Civic_number", "Floors_number", "Floors_number", "Gymnasium", "Gymnasium_swimming_pool",
                 "Solar_panels", "External_routes", "External_routes", "Internal_routes", "Internal_routes",
                 "Adaptation_period", "Building_period", "Emergency_plan", "Evacuation_plan",
                 "Elevator_platform", "Swimming_pool", "Bicycle_lane", "Weelchair_accessible_doors_width",
                 "Weelchair_accessible_doors_width", "Abandoned_industries", "Large_traffic",
                 "Railway_traffic", "Seismic_design", "Seismic_design", "Other_heating_system",
                 "Stairs_up_to_standard", "Stairs_up_to_standard", "Fire_prevention_activity_starting_notification", "School_bus",
                 "Disabled_people_compliant_sanitation","Disabled_people_compliant_sanitation", "Elevator_stairlift",
                 "Province_initials", "Administration_spaces", "Administration_spaces", "Collective_spaces",
                 "Teaching_spaces", "Teaching_spaces", "Free_area_surface", "School_area_surface",
                 "Building_status", "Architectural_barriers_overcoming_devices", "Free_area_surface", "School_area_surface",
                 "District_heating", "Address_type", "Railway_transport", "Interurban_public_transport",
                 "Urban_public_transport", "Disabled_people_transport", "School_use", "Double_windows_glazing",
                 "Polluted_waters_proximity", "Other_disturbances_proximity", "Graveyards_proximity", "Dumps_proximity",
                 "Acoustic_pollution_sources_proximity", "Air_pollution_sources_proximity",
                 "Hazardous_industries_proximity", "Pollutant_industries_proximity", "Acoustic_pollution_sources_proximity",
                 "Air_pollution_sources_proximity", "Electromagnetic_radiation_sources_proximity",
                 "Electromagnetic_radiation_sources_proximity", "Hydrogeological_restrictions", "Landscape_restrictions",
                 "Hydrogeological_restrictions", "Cultural_heritage_restrictions", "Landscape_restrictions", "Gross_building_volume",
                 "Gross_building_volume", "Seismic_zone", "Decayed_urban_area", "Heating_system_zoning")

  )
  return(manualdf)
}
